@@ -4,7 +4,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2020 Pascal Buchbinder
+ * Copyright (C) 2021 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -29,8 +29,8 @@
 /* ----------------------------------
  * version info
  * ---------------------------------- */
-static const char man_version[] = "11.66";
-static const char man_date[] = "May 2020";
+static const char man_version[] = "11.67";
+static const char man_date[] = "August 2021";
 
 /* ----------------------------------
  * definitions
